@@ -15,7 +15,8 @@ class UrlValidator(validator.StringValidator):
             pieces = urlparse.urlsplit(self.value)
 
             assert all([pieces.scheme, pieces.netloc])
-            assert set(pieces.hostname) <= set(string.letters + string.digits + '-.')
+            assert set(
+                pieces.hostname) <= set(string.letters + string.digits + '-.')
             assert pieces.scheme in ['http', 'https']
             return self
         except AssertionError:
