@@ -1,6 +1,6 @@
 from nagare import editor
 from css_crawler.lib.validator import UrlValidator
-from css_crawler.lib.i18n import *
+from css_crawler.lib.i18n import _
 
 
 class UrlFetcher(editor.Editor):
